# Configure paths for GiNaC
# Richard Kreckel 12/12/2000
# borrowed from Christian Bauer
# stolen from Sam Lantinga
# stolen from Manish Singh
# stolen back from Frank Belew
# stolen from Manish Singh
# Shamelessly stolen from Owen Taylor

dnl AM_PATH_GINAC([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for GiNaC, and define GINACLIB_CPPFLAGS and GINACLIB_LIBS
dnl
AC_DEFUN([AM_PATH_GINAC],
[dnl 
dnl Get the cppflags and libraries from the ginac-config script
dnl
AC_ARG_WITH(ginac-prefix,[  --with-ginac-prefix=PFX Prefix where GiNaC is installed (optional)],
            ginac_prefix="$withval", ginac_prefix="")
AC_ARG_WITH(ginac-exec-prefix,[  --with-ginac-exec-prefix=PFX Exec prefix where GiNaC is installed (optional)],
            ginac_exec_prefix="$withval", ginac_exec_prefix="")
AC_ARG_ENABLE(ginactest, [  --disable-ginactest     Do not try to compile and run a test GiNaC program],
              , enable_ginactest=yes)

if test x$ginac_exec_prefix != x ; then
    ginac_args="$ginac_args --exec-prefix=$ginac_exec_prefix"
    if test x${GINACLIB_CONFIG+set} != xset ; then
        GINACLIB_CONFIG=$ginac_exec_prefix/bin/ginac-config
    fi
fi
if test x$ginac_prefix != x ; then
    ginac_args="$ginac_args --prefix=$ginac_prefix"
    if test x${GINACLIB_CONFIG+set} != xset ; then
        GINACLIB_CONFIG=$ginac_prefix/bin/ginac-config
    fi
fi

AC_PATH_PROG(GINACLIB_CONFIG, ginac-config, no)
ginac_min_version=ifelse([$1], ,0.7.0,$1)
AC_MSG_CHECKING(for GiNaC - version >= $ginac_min_version)
if test "$GINACLIB_CONFIG" = "no" ; then
    AC_MSG_RESULT(no)
    echo "*** The ginac-config script installed by GiNaC could not be found"
    echo "*** If GiNaC was installed in PREFIX, make sure PREFIX/bin is in"
    echo "*** your path, or set the GINACLIB_CONFIG environment variable to the"
    echo "*** full path to ginac-config."
    ifelse([$3], , :, [$3])
else
dnl Parse required version and the result of ginac-config.
    ginac_min_major_version=`echo $ginac_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    ginac_min_minor_version=`echo $ginac_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    ginac_min_micro_version=`echo $ginac_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    GINACLIB_CPPFLAGS=`$GINACLIB_CONFIG $ginac_args --cppflags`
    GINACLIB_LIBS=`$GINACLIB_CONFIG $ginac_args --libs`
    ginac_config_version=`$GINACLIB_CONFIG $ginac_args --version`
    ginac_config_major_version=`echo $ginac_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    ginac_config_minor_version=`echo $ginac_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    ginac_config_micro_version=`echo $ginac_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
dnl Check if the installed GiNaC is sufficiently new according to ginac-config.
    if test \( $ginac_config_major_version -lt $ginac_min_major_version \) -o \
            \( $ginac_config_major_version -eq $ginac_min_major_version -a $ginac_config_minor_version -lt $ginac_min_minor_version \) -o \
            \( $ginac_config_major_version -eq $ginac_min_major_version -a $ginac_config_minor_version -eq $ginac_min_minor_version -a $ginac_config_micro_version -lt $ginac_min_micro_version \); then
        echo -e "\n*** 'ginac-config --version' returned $ginac_config_major_version.$ginac_config_minor_version.$ginac_config_micro_version, but the minimum version"
        echo "*** of GiNaC required is $ginac_min_major_version.$ginac_min_minor_version.$ginac_min_micro_version. If ginac-config is correct, then it is"
        echo "*** best to upgrade to the required version."
        echo "*** If ginac-config was wrong, set the environment variable GINACLIB_CONFIG"
        echo "*** to point to the correct copy of ginac-config, and remove the file"
        echo "*** config.cache before re-running configure."
        ifelse([$3], , :, [$3])
    else
dnl The versions match so far.  Now do a sanity check: Does the result of ginac-config
dnl match the version of the headers and the version built into the library, too?
        no_ginac=""
        if test "x$enable_ginactest" = "xyes" ; then
            ac_save_CPPFLAGS="$CPPFLAGS"
            ac_save_LIBS="$LIBS"
            CPPFLAGS="$CPPFLAGS $GINACLIB_CPPFLAGS"
            LIBS="$LIBS $GINACLIB_LIBS"
            rm -f conf.ginactest
            AC_TRY_RUN([
#include <stdio.h>
#include <string.h>
#include <ginac/version.h>

/* we do not #include <stdlib.h> because autoconf in C++ mode inserts a
   prototype for exit() that conflicts with the one in stdlib.h */
extern "C" int system(const char *);

int main(void)
{
    int major, minor, micro;
    char *tmp_version;

    system("touch conf.ginactest");

    if ((GINACLIB_MAJOR_VERSION != $ginac_config_major_version) ||
        (GINACLIB_MINOR_VERSION != $ginac_config_minor_version) ||
        (GINACLIB_MICRO_VERSION != $ginac_config_micro_version)) {
        printf("\n*** 'ginac-config --version' returned %d.%d.%d, but the header file I found\n", $ginac_config_major_version, $ginac_config_minor_version, $ginac_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of GiNaC\n", GINACLIB_MAJOR_VERSION, GINACLIB_MINOR_VERSION, GINACLIB_MICRO_VERSION);
        printf("*** is corrupted or you have specified some wrong -I compiler flags.\n");
        printf("*** Please inquire and consider reinstalling GiNaC.\n");
        return 1;
    }
    if ((GiNaC::version_major != $ginac_config_major_version) ||
        (GiNaC::version_minor != $ginac_config_minor_version) ||
        (GiNaC::version_micro != $ginac_config_micro_version)) {
        printf("\n*** 'ginac-config --version' returned %d.%d.%d, but the library I found\n", $ginac_config_major_version, $ginac_config_minor_version, $ginac_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of GiNaC\n", GiNaC::version_major, GiNaC::version_minor, GiNaC::version_micro);
        printf("*** is corrupted or you have specified some wrong -L compiler flags.\n");
        printf("*** Please inquire and consider reinstalling GiNaC.\n");
        return 1;
    }
    return 0;
}
],, no_ginac=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
            CPPFLAGS="$ac_save_CPPFLAGS"
            LIBS="$ac_save_LIBS"
        fi
        if test "x$no_ginac" = x ; then
            AC_MSG_RESULT([yes, $ginac_config_version])
            ifelse([$2], , :, [$2])
        else
            AC_MSG_RESULT(no)
            if test ! -f conf.ginactest ; then
                echo "*** Could not run GiNaC test program, checking why..."
                CPPFLAGS="$CFLAGS $GINACLIB_CPPFLAGS"
                LIBS="$LIBS $GINACLIB_LIBS"
                AC_TRY_LINK([
#include <stdio.h>
#include <ginac/version.h>
],              [ return 0; ],
                [ echo "*** The test program compiled, but did not run. This usually means"
                  echo "*** that the run-time linker is not finding GiNaC or finding the wrong"
                  echo "*** version of GiNaC. If it is not finding GiNaC, you'll need to set your"
                  echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
                  echo "*** to the installed location. Also, make sure you have run ldconfig if that"
                  echo "*** is required on your system."],
                [ echo "*** The test program failed to compile or link. See the file config.log for the"
                  echo "*** exact error that occured. This usually means GiNaC was incorrectly installed"
                  echo "*** or that you have moved GiNaC since it was installed. In the latter case, you"
                  echo "*** may want to edit the ginac-config script: $GINACLIB_CONFIG." ])
                CPPFLAGS="$ac_save_CPPFLAGS"
                LIBS="$ac_save_LIBS"
            fi
            GINACLIB_CPPFLAGS=""
            GINACLIB_LIBS=""
            ifelse([$3], , :, [$3])
        fi
    fi
fi
AC_SUBST(GINACLIB_CPPFLAGS)
AC_SUBST(GINACLIB_LIBS)
rm -f conf.ginactest
])

# ------------------------------------------------------------------

# Configure paths for GiNaC, has to match exact version
# Stefan Weinzierl 30/12/2001
# borrowed from Richard Kreckel
# borrowed from Christian Bauer
# stolen from Sam Lantinga
# stolen from Manish Singh
# stolen back from Frank Belew
# stolen from Manish Singh
# Shamelessly stolen from Owen Taylor

dnl AM_PATH_GINAC_EXACT([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for GiNaC, and define GINACLIB_CPPFLAGS and GINACLIB_LIBS
dnl
AC_DEFUN([AM_PATH_GINAC_EXACT],
[dnl 
dnl Get the cppflags and libraries from the ginac-config script
dnl
AC_ARG_WITH(ginac-prefix,[  --with-ginac-prefix=PFX Prefix where GiNaC is installed (optional)],
            ginac_prefix="$withval", ginac_prefix="")
AC_ARG_WITH(ginac-exec-prefix,[  --with-ginac-exec-prefix=PFX Exec prefix where GiNaC is installed (optional)],
            ginac_exec_prefix="$withval", ginac_exec_prefix="")
AC_ARG_ENABLE(ginactest, [  --disable-ginactest     Do not try to compile and run a test GiNaC program],
              , enable_ginactest=yes)

if test x$ginac_exec_prefix != x ; then
    ginac_args="$ginac_args --exec-prefix=$ginac_exec_prefix"
    if test x${GINACLIB_CONFIG+set} != xset ; then
        GINACLIB_CONFIG=$ginac_exec_prefix/bin/ginac-config
    fi
fi
if test x$ginac_prefix != x ; then
    ginac_args="$ginac_args --prefix=$ginac_prefix"
    if test x${GINACLIB_CONFIG+set} != xset ; then
        GINACLIB_CONFIG=$ginac_prefix/bin/ginac-config
    fi
fi

AC_PATH_PROG(GINACLIB_CONFIG, ginac-config, no)
ginac_min_version=ifelse([$1], ,0.7.0,$1)
AC_MSG_CHECKING(for GiNaC - version = $ginac_min_version)
if test "$GINACLIB_CONFIG" = "no" ; then
    AC_MSG_RESULT(no)
    echo "*** The ginac-config script installed by GiNaC could not be found"
    echo "*** If GiNaC was installed in PREFIX, make sure PREFIX/bin is in"
    echo "*** your path, or set the GINACLIB_CONFIG environment variable to the"
    echo "*** full path to ginac-config."
    ifelse([$3], , :, [$3])
else
dnl Parse required version and the result of ginac-config.
    ginac_min_major_version=`echo $ginac_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    ginac_min_minor_version=`echo $ginac_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    ginac_min_micro_version=`echo $ginac_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    GINACLIB_CPPFLAGS=`$GINACLIB_CONFIG $ginac_args --cppflags`
    GINACLIB_LIBS=`$GINACLIB_CONFIG $ginac_args --libs`
    ginac_config_version=`$GINACLIB_CONFIG $ginac_args --version`
    ginac_config_major_version=`echo $ginac_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    ginac_config_minor_version=`echo $ginac_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    ginac_config_micro_version=`echo $ginac_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
dnl Check if the installed GiNaC is sufficiently new according to ginac-config.
    if test \( $ginac_config_major_version -ne $ginac_min_major_version -o $ginac_config_minor_version -ne $ginac_min_minor_version -o $ginac_config_micro_version -ne $ginac_min_micro_version \); then
        echo -e "\n*** 'ginac-config --version' returned $ginac_config_major_version.$ginac_config_minor_version.$ginac_config_micro_version, but the version"
        echo "*** of GiNaC required is $ginac_min_major_version.$ginac_min_minor_version.$ginac_min_micro_version. If ginac-config is correct, then it is"
        echo "*** best to upgrade to the required version."
        echo "*** If ginac-config was wrong, set the environment variable GINACLIB_CONFIG"
        echo "*** to point to the correct copy of ginac-config, and remove the file"
        echo "*** config.cache before re-running configure."
        ifelse([$3], , :, [$3])
    else
dnl The versions match so far.  Now do a sanity check: Does the result of ginac-config
dnl match the version of the headers and the version built into the library, too?
        no_ginac=""
        if test "x$enable_ginactest" = "xyes" ; then
            ac_save_CPPFLAGS="$CPPFLAGS"
            ac_save_LIBS="$LIBS"
            CPPFLAGS="$CPPFLAGS $GINACLIB_CPPFLAGS"
            LIBS="$LIBS $GINACLIB_LIBS"
            rm -f conf.ginactest
            AC_TRY_RUN([
#include <stdio.h>
#include <string.h>
#include <ginac/version.h>

/* we do not #include <stdlib.h> because autoconf in C++ mode inserts a
   prototype for exit() that conflicts with the one in stdlib.h */
extern "C" int system(const char *);

int main(void)
{
    int major, minor, micro;
    char *tmp_version;

    system("touch conf.ginactest");

    if ((GINACLIB_MAJOR_VERSION != $ginac_config_major_version) ||
        (GINACLIB_MINOR_VERSION != $ginac_config_minor_version) ||
        (GINACLIB_MICRO_VERSION != $ginac_config_micro_version)) {
        printf("\n*** 'ginac-config --version' returned %d.%d.%d, but the header file I found\n", $ginac_config_major_version, $ginac_config_minor_version, $ginac_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of GiNaC\n", GINACLIB_MAJOR_VERSION, GINACLIB_MINOR_VERSION, GINACLIB_MICRO_VERSION);
        printf("*** is corrupted or you have specified some wrong -I compiler flags.\n");
        printf("*** Please inquire and consider reinstalling GiNaC.\n");
        return 1;
    }
    if ((GiNaC::version_major != $ginac_config_major_version) ||
        (GiNaC::version_minor != $ginac_config_minor_version) ||
        (GiNaC::version_micro != $ginac_config_micro_version)) {
        printf("\n*** 'ginac-config --version' returned %d.%d.%d, but the library I found\n", $ginac_config_major_version, $ginac_config_minor_version, $ginac_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of GiNaC\n", GiNaC::version_major, GiNaC::version_minor, GiNaC::version_micro);
        printf("*** is corrupted or you have specified some wrong -L compiler flags.\n");
        printf("*** Please inquire and consider reinstalling GiNaC.\n");
        return 1;
    }
    return 0;
}
],, no_ginac=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
            CPPFLAGS="$ac_save_CPPFLAGS"
            LIBS="$ac_save_LIBS"
        fi
        if test "x$no_ginac" = x ; then
            AC_MSG_RESULT([yes, $ginac_config_version])
            ifelse([$2], , :, [$2])
        else
            AC_MSG_RESULT(no)
            if test ! -f conf.ginactest ; then
                echo "*** Could not run GiNaC test program, checking why..."
                CPPFLAGS="$CFLAGS $GINACLIB_CPPFLAGS"
                LIBS="$LIBS $GINACLIB_LIBS"
                AC_TRY_LINK([
#include <stdio.h>
#include <ginac/version.h>
],              [ return 0; ],
                [ echo "*** The test program compiled, but did not run. This usually means"
                  echo "*** that the run-time linker is not finding GiNaC or finding the wrong"
                  echo "*** version of GiNaC. If it is not finding GiNaC, you'll need to set your"
                  echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
                  echo "*** to the installed location. Also, make sure you have run ldconfig if that"
                  echo "*** is required on your system."],
                [ echo "*** The test program failed to compile or link. See the file config.log for the"
                  echo "*** exact error that occured. This usually means GiNaC was incorrectly installed"
                  echo "*** or that you have moved GiNaC since it was installed. In the latter case, you"
                  echo "*** may want to edit the ginac-config script: $GINACLIB_CONFIG." ])
                CPPFLAGS="$ac_save_CPPFLAGS"
                LIBS="$ac_save_LIBS"
            fi
            GINACLIB_CPPFLAGS=""
            GINACLIB_LIBS=""
            ifelse([$3], , :, [$3])
        fi
    fi
fi
AC_SUBST(GINACLIB_CPPFLAGS)
AC_SUBST(GINACLIB_LIBS)
rm -f conf.ginactest
])

# ------------------------------------------------------------------

# Configure paths for nestedsums
# Christian Bauer 24.Mar.2003
# stolen from Sam Lantinga
# stolen from Manish Singh
# stolen back from Frank Belew
# stolen from Manish Singh
# Shamelessly stolen from Owen Taylor

dnl AM_PATH_NESTEDSUMS([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for nestedsums, and define NESTEDSUMS_CPPFLAGS and NESTEDSUMS_LIBS
dnl
AC_DEFUN([AM_PATH_NESTEDSUMS],
[dnl 
dnl Get the cppflags and libraries from the nestedsums-config script
dnl
AC_ARG_WITH(nestedsums-prefix,[  --with-nestedsums-prefix=PFX Prefix where nestedsums is installed (optional)],
            nestedsums_prefix="$withval", nestedsums_prefix="")
AC_ARG_WITH(nestedsums-exec-prefix,[  --with-nestedsums-exec-prefix=PFX Exec prefix where nestedsums is installed (optional)],
            nestedsums_exec_prefix="$withval", nestedsums_exec_prefix="")
AC_ARG_ENABLE(nestedsumstest, [  --disable-nestedsumstest     Do not try to compile and run a test nestedsums program],
              , enable_nestedsumstest=yes)

if test x$nestedsums_exec_prefix != x ; then
    nestedsums_args="$nestedsums_args --exec-prefix=$nestedsums_exec_prefix"
    if test x${NESTEDSUMS_CONFIG+set} != xset ; then
        NESTEDSUMS_CONFIG=$nestedsums_exec_prefix/bin/nestedsums-config
    fi
fi
if test x$nestedsums_prefix != x ; then
    nestedsums_args="$nestedsums_args --prefix=$nestedsums_prefix"
    if test x${NESTEDSUMS_CONFIG+set} != xset ; then
        NESTEDSUMS_CONFIG=$nestedsums_prefix/bin/nestedsums-config
    fi
fi

AC_PATH_PROG(NESTEDSUMS_CONFIG, nestedsums-config, no)
nestedsums_min_version=ifelse([$1], ,1.1.0,$1)
AC_MSG_CHECKING(for nestedsums - version >= $nestedsums_min_version)
if test "$NESTEDSUMS_CONFIG" = "no" ; then
    AC_MSG_RESULT(no)
    echo "*** The nestedsums-config script installed by nestedsums could not be found"
    echo "*** If nestedsums was installed in PREFIX, make sure PREFIX/bin is in"
    echo "*** your path, or set the NESTEDSUMS_CONFIG environment variable to the"
    echo "*** full path to nestedsums-config."
    ifelse([$3], , :, [$3])
else
dnl Parse required version and the result of nestedsums-config.
    nestedsums_min_major_version=`echo $nestedsums_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    nestedsums_min_minor_version=`echo $nestedsums_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    nestedsums_min_micro_version=`echo $nestedsums_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    NESTEDSUMS_CPPFLAGS=`$NESTEDSUMS_CONFIG $nestedsums_args --cppflags`
    NESTEDSUMS_LIBS=`$NESTEDSUMS_CONFIG $nestedsums_args --libs`
    nestedsums_config_version=`$NESTEDSUMS_CONFIG $nestedsums_args --version`
    nestedsums_config_major_version=`echo $nestedsums_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    nestedsums_config_minor_version=`echo $nestedsums_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    nestedsums_config_micro_version=`echo $nestedsums_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
dnl Check if the installed nestedsums is sufficiently new according to nestedsums-config.
    if test \( $nestedsums_config_major_version -lt $nestedsums_min_major_version \) -o \
            \( $nestedsums_config_major_version -eq $nestedsums_min_major_version -a $nestedsums_config_minor_version -lt $nestedsums_min_minor_version \) -o \
            \( $nestedsums_config_major_version -eq $nestedsums_min_major_version -a $nestedsums_config_minor_version -eq $nestedsums_min_minor_version -a $nestedsums_config_micro_version -lt $nestedsums_min_micro_version \); then
        echo -e "\n*** 'nestedsums-config --version' returned $nestedsums_config_major_version.$nestedsums_config_minor_version.$nestedsums_config_micro_version, but the minimum version"
        echo "*** of nestedsums required is $nestedsums_min_major_version.$nestedsums_min_minor_version.$nestedsums_min_micro_version. If nestedsums-config is correct, then it is"
        echo "*** best to upgrade to the required version."
        echo "*** If nestedsums-config was wrong, set the environment variable NESTEDSUMS_CONFIG"
        echo "*** to point to the correct copy of nestedsums-config, and remove the file"
        echo "*** config.cache before re-running configure."
        ifelse([$3], , :, [$3])
    else
dnl The versions match so far.  Now do a sanity check: Does the result of nestedsums-config
dnl match the version of the headers and the version built into the library, too?
        no_nestedsums=""
        if test "x$enable_nestedsumstest" = "xyes" ; then
            ac_save_CPPFLAGS="$CPPFLAGS"
            ac_save_LIBS="$LIBS"
            CPPFLAGS="$CPPFLAGS $NESTEDSUMS_CPPFLAGS"
            LIBS="$LIBS $NESTEDSUMS_LIBS"
            rm -f conf.nestedsumstest
            AC_TRY_RUN([
#include <stdio.h>
#include <string.h>
#include <nestedsums/version.h>

/* we do not #include <stdlib.h> because autoconf in C++ mode inserts a
   prototype for exit() that conflicts with the one in stdlib.h */
extern "C" int system(const char *);

int main(void)
{
    int major, minor, micro;
    char *tmp_version;

    system("touch conf.nestedsumstest");

    if ((NESTEDSUMS_MAJOR != $nestedsums_config_major_version) ||
        (NESTEDSUMS_MINOR != $nestedsums_config_minor_version) ||
        (NESTEDSUMS_MICRO != $nestedsums_config_micro_version)) {
        printf("\n*** 'nestedsums-config --version' returned %d.%d.%d, but the header file I found\n", $nestedsums_config_major_version, $nestedsums_config_minor_version, $nestedsums_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of nestedsums\n", NESTEDSUMS_MAJOR, NESTEDSUMS_MINOR, NESTEDSUMS_MICRO);
        printf("*** is corrupted or you have specified some wrong -I compiler flags.\n");
        printf("*** Please inquire and consider reinstalling nestedsums.\n");
        return 1;
    }
    if ((nestedsums::version_major != $nestedsums_config_major_version) ||
        (nestedsums::version_minor != $nestedsums_config_minor_version) ||
        (nestedsums::version_micro != $nestedsums_config_micro_version)) {
        printf("\n*** 'nestedsums-config --version' returned %d.%d.%d, but the library I found\n", $nestedsums_config_major_version, $nestedsums_config_minor_version, $nestedsums_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of nestedsums\n", nestedsums::version_major, nestedsums::version_minor, nestedsums::version_micro);
        printf("*** is corrupted or you have specified some wrong -L compiler flags.\n");
        printf("*** Please inquire and consider reinstalling nestedsums.\n");
        return 1;
    }
    return 0;
}
],, no_nestedsums=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
            CPPFLAGS="$ac_save_CPPFLAGS"
            LIBS="$ac_save_LIBS"
        fi
        if test "x$no_nestedsums" = x ; then
            AC_MSG_RESULT([yes, $nestedsums_config_version])
            ifelse([$2], , :, [$2])
        else
            AC_MSG_RESULT(no)
            if test ! -f conf.nestedsumstest ; then
                echo "*** Could not run nestedsums test program, checking why..."
                CPPFLAGS="$CFLAGS $NESTEDSUMS_CPPFLAGS"
                LIBS="$LIBS $NESTEDSUMS_LIBS"
                AC_TRY_LINK([
#include <stdio.h>
#include <nestedsums/version.h>
],              [ return 0; ],
                [ echo "*** The test program compiled, but did not run. This usually means"
                  echo "*** that the run-time linker is not finding nestedsums or finding the wrong"
                  echo "*** version of nestedsums. If it is not finding nestedsums, you'll need to set your"
                  echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
                  echo "*** to the installed location. Also, make sure you have run ldconfig if that"
                  echo "*** is required on your system."],
                [ echo "*** The test program failed to compile or link. See the file config.log for the"
                  echo "*** exact error that occured. This usually means nestedsums was incorrectly installed"
                  echo "*** or that you have moved nestedsums since it was installed. In the latter case, you"
                  echo "*** may want to edit the nestedsums-config script: $NESTEDSUMS_CONFIG." ])
                CPPFLAGS="$ac_save_CPPFLAGS"
                LIBS="$ac_save_LIBS"
            fi
            NESTEDSUMS_CPPFLAGS=""
            NESTEDSUMS_LIBS=""
            ifelse([$3], , :, [$3])
        fi
    fi
fi
AC_SUBST(NESTEDSUMS_CPPFLAGS)
AC_SUBST(NESTEDSUMS_LIBS)
rm -f conf.nestedsumstest
])

# ------------------------------------------------------------------

# Configure paths for nestedsums, has to match exact version
# Stefan Weinzierl 27.08.2003
# stolen from Christian Bauer 
# stolen from Sam Lantinga
# stolen from Manish Singh
# stolen back from Frank Belew
# stolen from Manish Singh
# Shamelessly stolen from Owen Taylor

dnl AM_PATH_NESTEDSUMS_EXACT([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for nestedsums, and define NESTEDSUMS_CPPFLAGS and NESTEDSUMS_LIBS
dnl
AC_DEFUN([AM_PATH_NESTEDSUMS_EXACT],
[dnl 
dnl Get the cppflags and libraries from the nestedsums-config script
dnl
AC_ARG_WITH(nestedsums-prefix,[  --with-nestedsums-prefix=PFX Prefix where nestedsums is installed (optional)],
            nestedsums_prefix="$withval", nestedsums_prefix="")
AC_ARG_WITH(nestedsums-exec-prefix,[  --with-nestedsums-exec-prefix=PFX Exec prefix where nestedsums is installed (optional)],
            nestedsums_exec_prefix="$withval", nestedsums_exec_prefix="")
AC_ARG_ENABLE(nestedsumstest, [  --disable-nestedsumstest     Do not try to compile and run a test nestedsums program],
              , enable_nestedsumstest=yes)

if test x$nestedsums_exec_prefix != x ; then
    nestedsums_args="$nestedsums_args --exec-prefix=$nestedsums_exec_prefix"
    if test x${NESTEDSUMS_CONFIG+set} != xset ; then
        NESTEDSUMS_CONFIG=$nestedsums_exec_prefix/bin/nestedsums-config
    fi
fi
if test x$nestedsums_prefix != x ; then
    nestedsums_args="$nestedsums_args --prefix=$nestedsums_prefix"
    if test x${NESTEDSUMS_CONFIG+set} != xset ; then
        NESTEDSUMS_CONFIG=$nestedsums_prefix/bin/nestedsums-config
    fi
fi

AC_PATH_PROG(NESTEDSUMS_CONFIG, nestedsums-config, no)
nestedsums_min_version=ifelse([$1], ,1.1.0,$1)
AC_MSG_CHECKING(for nestedsums - version = $nestedsums_min_version)
if test "$NESTEDSUMS_CONFIG" = "no" ; then
    AC_MSG_RESULT(no)
    echo "*** The nestedsums-config script installed by nestedsums could not be found"
    echo "*** If nestedsums was installed in PREFIX, make sure PREFIX/bin is in"
    echo "*** your path, or set the NESTEDSUMS_CONFIG environment variable to the"
    echo "*** full path to nestedsums-config."
    ifelse([$3], , :, [$3])
else
dnl Parse required version and the result of nestedsums-config.
    nestedsums_min_major_version=`echo $nestedsums_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    nestedsums_min_minor_version=`echo $nestedsums_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    nestedsums_min_micro_version=`echo $nestedsums_min_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    NESTEDSUMS_CPPFLAGS=`$NESTEDSUMS_CONFIG $nestedsums_args --cppflags`
    NESTEDSUMS_LIBS=`$NESTEDSUMS_CONFIG $nestedsums_args --libs`
    nestedsums_config_version=`$NESTEDSUMS_CONFIG $nestedsums_args --version`
    nestedsums_config_major_version=`echo $nestedsums_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    nestedsums_config_minor_version=`echo $nestedsums_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    nestedsums_config_micro_version=`echo $nestedsums_config_version | \
            sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
dnl Check if the installed nestedsums is sufficiently new according to nestedsums-config.
    if test \( $nestedsums_config_major_version -ne $nestedsums_min_major_version -o $nestedsums_config_minor_version -ne $nestedsums_min_minor_version -o $nestedsums_config_micro_version -ne $nestedsums_min_micro_version \); then
        echo -e "\n*** 'nestedsums-config --version' returned $nestedsums_config_major_version.$nestedsums_config_minor_version.$nestedsums_config_micro_version, but the version"
        echo "*** of nestedsums required is $nestedsums_min_major_version.$nestedsums_min_minor_version.$nestedsums_min_micro_version. If nestedsums-config is correct, then it is"
        echo "*** best to upgrade to the required version."
        echo "*** If nestedsums-config was wrong, set the environment variable NESTEDSUMS_CONFIG"
        echo "*** to point to the correct copy of nestedsums-config, and remove the file"
        echo "*** config.cache before re-running configure."
        ifelse([$3], , :, [$3])
    else
dnl The versions match so far.  Now do a sanity check: Does the result of nestedsums-config
dnl match the version of the headers and the version built into the library, too?
        no_nestedsums=""
        if test "x$enable_nestedsumstest" = "xyes" ; then
            ac_save_CPPFLAGS="$CPPFLAGS"
            ac_save_LIBS="$LIBS"
            CPPFLAGS="$CPPFLAGS $NESTEDSUMS_CPPFLAGS"
            LIBS="$LIBS $NESTEDSUMS_LIBS"
            rm -f conf.nestedsumstest
            AC_TRY_RUN([
#include <stdio.h>
#include <string.h>
#include <nestedsums/version.h>

/* we do not #include <stdlib.h> because autoconf in C++ mode inserts a
   prototype for exit() that conflicts with the one in stdlib.h */
extern "C" int system(const char *);

int main(void)
{
    int major, minor, micro;
    char *tmp_version;

    system("touch conf.nestedsumstest");

    if ((NESTEDSUMS_MAJOR != $nestedsums_config_major_version) ||
        (NESTEDSUMS_MINOR != $nestedsums_config_minor_version) ||
        (NESTEDSUMS_MICRO != $nestedsums_config_micro_version)) {
        printf("\n*** 'nestedsums-config --version' returned %d.%d.%d, but the header file I found\n", $nestedsums_config_major_version, $nestedsums_config_minor_version, $nestedsums_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of nestedsums\n", NESTEDSUMS_MAJOR, NESTEDSUMS_MINOR, NESTEDSUMS_MICRO);
        printf("*** is corrupted or you have specified some wrong -I compiler flags.\n");
        printf("*** Please inquire and consider reinstalling nestedsums.\n");
        return 1;
    }
    if ((nestedsums::version_major != $nestedsums_config_major_version) ||
        (nestedsums::version_minor != $nestedsums_config_minor_version) ||
        (nestedsums::version_micro != $nestedsums_config_micro_version)) {
        printf("\n*** 'nestedsums-config --version' returned %d.%d.%d, but the library I found\n", $nestedsums_config_major_version, $nestedsums_config_minor_version, $nestedsums_config_micro_version);
        printf("*** corresponds to %d.%d.%d. This mismatch suggests your installation of nestedsums\n", nestedsums::version_major, nestedsums::version_minor, nestedsums::version_micro);
        printf("*** is corrupted or you have specified some wrong -L compiler flags.\n");
        printf("*** Please inquire and consider reinstalling nestedsums.\n");
        return 1;
    }
    return 0;
}
],, no_nestedsums=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
            CPPFLAGS="$ac_save_CPPFLAGS"
            LIBS="$ac_save_LIBS"
        fi
        if test "x$no_nestedsums" = x ; then
            AC_MSG_RESULT([yes, $nestedsums_config_version])
            ifelse([$2], , :, [$2])
        else
            AC_MSG_RESULT(no)
            if test ! -f conf.nestedsumstest ; then
                echo "*** Could not run nestedsums test program, checking why..."
                CPPFLAGS="$CFLAGS $NESTEDSUMS_CPPFLAGS"
                LIBS="$LIBS $NESTEDSUMS_LIBS"
                AC_TRY_LINK([
#include <stdio.h>
#include <nestedsums/version.h>
],              [ return 0; ],
                [ echo "*** The test program compiled, but did not run. This usually means"
                  echo "*** that the run-time linker is not finding nestedsums or finding the wrong"
                  echo "*** version of nestedsums. If it is not finding nestedsums, you'll need to set your"
                  echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
                  echo "*** to the installed location. Also, make sure you have run ldconfig if that"
                  echo "*** is required on your system."],
                [ echo "*** The test program failed to compile or link. See the file config.log for the"
                  echo "*** exact error that occured. This usually means nestedsums was incorrectly installed"
                  echo "*** or that you have moved nestedsums since it was installed. In the latter case, you"
                  echo "*** may want to edit the nestedsums-config script: $NESTEDSUMS_CONFIG." ])
                CPPFLAGS="$ac_save_CPPFLAGS"
                LIBS="$ac_save_LIBS"
            fi
            NESTEDSUMS_CPPFLAGS=""
            NESTEDSUMS_LIBS=""
            ifelse([$3], , :, [$3])
        fi
    fi
fi
AC_SUBST(NESTEDSUMS_CPPFLAGS)
AC_SUBST(NESTEDSUMS_LIBS)
rm -f conf.nestedsumstest
])

# ------------------------------------------------------------------

dnl configure path for Root
dnl modified by Stefan Weinzierl
dnl
dnl $Id: root.m4,v 1.2 2002/07/31 20:45:09 rdm Exp $
dnl $Author: rdm $
dnl $Date: 2002/07/31 20:45:09 $
dnl
dnl Autoconf macro to check for existence or ROOT on the system
dnl Synopsis:
dnl
dnl  ROOT_PATH([MINIMUM-VERSION, [ACTION-IF-FOUND, [ACTION-IF-NOT-FOUND]]])
dnl
dnl Some examples: 
dnl 
dnl    ROOT_PATH(3.03/05, , AC_MSG_ERROR(Your ROOT version is too old))
dnl 
dnl The macro defines the following substitution variables
dnl
dnl    ROOTCONF           full path to root-config
dnl    ROOTEXEC           full path to root
dnl    ROOTCINT           full path to rootcint
dnl    ROOT_CPPFLAGS      Compiler flags
dnl    ROOT_LIBS          ROOT basic libraries 
dnl    ROOT_GLIBS         ROOT basic + GUI libraries
dnl
dnl The macro will fail if root-config and rootcint isn't found.
dnl
dnl Christian Holm Christensen <cholm@nbi.dk>
dnl
AC_DEFUN([ROOT_PATH],
[
  AC_ARG_WITH(rootsys,
  [  --with-rootsys          top of the ROOT installation directory],
    user_rootsys=$withval,
    user_rootsys="none")
  if test ! x"$user_rootsys" = xnone; then
    rootbin="$user_rootsys/bin"
  elif test ! x"$ROOTSYS" = x ; then 
    rootbin="$ROOTSYS/bin"
  else 
   rootbin=$PATH
  fi
  AC_PATH_PROG(ROOTCONF, root-config , no, $rootbin)
  AC_PATH_PROG(ROOTEXEC, root , no, $rootbin)
  AC_PATH_PROG(ROOTCINT, rootcint , no, $rootbin)
	
  if test ! x"$ROOTCONF" = "xno" && \
     test ! x"$ROOTCINT" = "xno" ; then 

    # define some variables 
    ROOT_CPPFLAGS=`$ROOTCONF --cflags` 
    ROOT_LIBS=`$ROOTCONF --libs`
    ROOT_GLIBS=`$ROOTCONF --glibs`
	
    if test $1 ; then 
      AC_MSG_CHECKING(wether ROOT version >= [$1])
      vers=`$ROOTCONF --version | tr './' ' ' | awk 'BEGIN { FS = " "; } { printf "%d", ($''1 * 1000 + $''2) * 1000 + $''3;}'`
      requ=`echo $1 | tr './' ' ' | awk 'BEGIN { FS = " "; } { printf "%d", ($''1 * 1000 + $''2) * 1000 + $''3;}'`
      if test $vers -lt $requ ; then 
        AC_MSG_RESULT(no)
	no_root="yes"
      else 
        AC_MSG_RESULT(yes)
      fi
    fi
  else
    # otherwise, we say no_root
    no_root="yes"
  fi

  AC_SUBST(ROOT_CPPFLAGS)
  AC_SUBST(ROOT_LIBS)
  AC_SUBST(ROOT_GLIBS) 

  if test "x$no_root" = "x" ; then 
    ifelse([$2], , :, [$2])     
  else 
    ifelse([$3], , :, [$3])     
  fi
])

# ------------------------------------------------------------------

dnl configure path for Root, requires exact version
dnl modified by Stefan Weinzierl
dnl
dnl $Id: root.m4,v 1.2 2002/07/31 20:45:09 rdm Exp $
dnl $Author: rdm $
dnl $Date: 2002/07/31 20:45:09 $
dnl
dnl Autoconf macro to check for existence or ROOT on the system
dnl Synopsis:
dnl
dnl  ROOT_PATH_EXACT([VERSION, [ACTION-IF-FOUND, [ACTION-IF-NOT-FOUND]]])
dnl
dnl Some examples: 
dnl 
dnl    ROOT_PATH(3.03/05, , AC_MSG_ERROR(Your ROOT version is too old))
dnl 
dnl The macro defines the following substitution variables
dnl
dnl    ROOTCONF           full path to root-config
dnl    ROOTEXEC           full path to root
dnl    ROOTCINT           full path to rootcint
dnl    ROOT_CPPFLAGS      Compiler flags
dnl    ROOT_LIBS          ROOT basic libraries 
dnl    ROOT_GLIBS         ROOT basic + GUI libraries
dnl
dnl The macro will fail if root-config and rootcint isn't found.
dnl
dnl Christian Holm Christensen <cholm@nbi.dk>
dnl
AC_DEFUN([ROOT_PATH_EXACT],
[
  AC_ARG_WITH(rootsys,
  [  --with-rootsys          top of the ROOT installation directory],
    user_rootsys=$withval,
    user_rootsys="none")
  if test ! x"$user_rootsys" = xnone; then
    rootbin="$user_rootsys/bin"
  elif test ! x"$ROOTSYS" = x ; then 
    rootbin="$ROOTSYS/bin"
  else 
   rootbin=$PATH
  fi
  AC_PATH_PROG(ROOTCONF, root-config , no, $rootbin)
  AC_PATH_PROG(ROOTEXEC, root , no, $rootbin)
  AC_PATH_PROG(ROOTCINT, rootcint , no, $rootbin)
	
  if test ! x"$ROOTCONF" = "xno" && \
     test ! x"$ROOTCINT" = "xno" ; then 

    # define some variables 
    ROOT_CPPFLAGS=`$ROOTCONF --cflags` 
    ROOT_LIBS=`$ROOTCONF --libs`
    ROOT_GLIBS=`$ROOTCONF --glibs`
	
    if test $1 ; then 
      AC_MSG_CHECKING(wether ROOT version = [$1])
      vers=`$ROOTCONF --version | tr './' ' ' | awk 'BEGIN { FS = " "; } { printf "%d", ($''1 * 1000 + $''2) * 1000 + $''3;}'`
      requ=`echo $1 | tr './' ' ' | awk 'BEGIN { FS = " "; } { printf "%d", ($''1 * 1000 + $''2) * 1000 + $''3;}'`
      if test $vers -ne $requ ; then 
        AC_MSG_RESULT(no)
	no_root="yes"
      else 
        AC_MSG_RESULT(yes)
      fi
    fi
  else
    # otherwise, we say no_root
    no_root="yes"
  fi

  AC_SUBST(ROOT_CPPFLAGS)
  AC_SUBST(ROOT_LIBS)
  AC_SUBST(ROOT_GLIBS) 

  if test "x$no_root" = "x" ; then 
    ifelse([$2], , :, [$2])     
  else 
    ifelse([$3], , :, [$3])     
  fi
])

# ------------------------------------------------------------------
# Configure path for the GNU Scientific Library
# Christopher R. Gabriel <cgabriel@linux.it>, April 2000


AC_DEFUN([AM_PATH_GSL],
[
AC_ARG_WITH(gsl-prefix,[  --with-gsl-prefix=PFX   Prefix where GSL is installed (optional)],
            gsl_prefix="$withval", gsl_prefix="")
AC_ARG_WITH(gsl-exec-prefix,[  --with-gsl-exec-prefix=PFX Exec prefix where GSL is installed (optional)],
            gsl_exec_prefix="$withval", gsl_exec_prefix="")
AC_ARG_ENABLE(gsltest, [  --disable-gsltest       Do not try to compile and run a test GSL program],
		    , enable_gsltest=yes)

  if test "x${GSL_CONFIG+set}" != xset ; then
     if test "x$gsl_prefix" != x ; then
         GSL_CONFIG="$gsl_prefix/bin/gsl-config"
     fi
     if test "x$gsl_exec_prefix" != x ; then
        GSL_CONFIG="$gsl_exec_prefix/bin/gsl-config"
     fi
  fi

  AC_PATH_PROG(GSL_CONFIG, gsl-config, no)
  min_gsl_version=ifelse([$1], ,0.2.5,$1)
  AC_MSG_CHECKING(for GSL - version >= $min_gsl_version)
  no_gsl=""
  if test "$GSL_CONFIG" = "no" ; then
    no_gsl=yes
  else
    GSL_CFLAGS=`$GSL_CONFIG --cflags`
    GSL_LIBS=`$GSL_CONFIG --libs`

    gsl_major_version=`$GSL_CONFIG --version | \
           sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${gsl_major_version}" = "x" ; then
       gsl_major_version=0
    fi

    gsl_minor_version=`$GSL_CONFIG --version | \
           sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${gsl_minor_version}" = "x" ; then
       gsl_minor_version=0
    fi

    gsl_micro_version=`$GSL_CONFIG --version | \
           sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${gsl_micro_version}" = "x" ; then
       gsl_micro_version=0
    fi

    if test "x$enable_gsltest" = "xyes" ; then
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $GSL_CFLAGS"
      LIBS="$LIBS $GSL_LIBS"

      rm -f conf.gsltest
      AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

char* my_strdup (const char *str);

char*
my_strdup (const char *str)
{
  char *new_str;
  
  if (str)
    {
      new_str = (char *)malloc ((strlen (str) + 1) * sizeof(char));
      strcpy (new_str, str);
    }
  else
    new_str = NULL;
  
  return new_str;
}

int main (void)
{
  int major = 0, minor = 0, micro = 0;
  int n;
  char *tmp_version;

  system ("touch conf.gsltest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_gsl_version");

  n = sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) ;

  if (n != 2 && n != 3) {
     printf("%s, bad version string\n", "$min_gsl_version");
     exit(1);
   }

   if (($gsl_major_version > major) ||
      (($gsl_major_version == major) && ($gsl_minor_version > minor)) ||
      (($gsl_major_version == major) && ($gsl_minor_version == minor) && ($gsl_micro_version >= micro)))
    {
      exit(0);
    }
  else
    {
      printf("\n*** 'gsl-config --version' returned %d.%d.%d, but the minimum version\n", $gsl_major_version, $gsl_minor_version, $gsl_micro_version);
      printf("*** of GSL required is %d.%d.%d. If gsl-config is correct, then it is\n", major, minor, micro);
      printf("*** best to upgrade to the required version.\n");
      printf("*** If gsl-config was wrong, set the environment variable GSL_CONFIG\n");
      printf("*** to point to the correct copy of gsl-config, and remove the file\n");
      printf("*** config.cache before re-running configure\n");
      exit(1);
    }
}

],, no_gsl=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
     fi
  fi
  if test "x$no_gsl" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$GSL_CONFIG" = "no" ; then
       echo "*** The gsl-config script installed by GSL could not be found"
       echo "*** If GSL was installed in PREFIX, make sure PREFIX/bin is in"
       echo "*** your path, or set the GSL_CONFIG environment variable to the"
       echo "*** full path to gsl-config."
     else
       if test -f conf.gsltest ; then
        :
       else
          echo "*** Could not run GSL test program, checking why..."
          CFLAGS="$CFLAGS $GSL_CFLAGS"
          LIBS="$LIBS $GSL_LIBS"
          AC_TRY_LINK([
#include <stdio.h>
],      [ return 0; ],
        [ echo "*** The test program compiled, but did not run. This usually means"
          echo "*** that the run-time linker is not finding GSL or finding the wrong"
          echo "*** version of GSL. If it is not finding GSL, you'll need to set your"
          echo "*** LD_LIBRARY_PATH environment variable, or edit /etc/ld.so.conf to point"
          echo "*** to the installed location  Also, make sure you have run ldconfig if that"
          echo "*** is required on your system"
	  echo "***"
          echo "*** If you have an old version installed, it is best to remove it, although"
          echo "*** you may also be able to get things to work by modifying LD_LIBRARY_PATH"],
        [ echo "*** The test program failed to compile or link. See the file config.log for the"
          echo "*** exact error that occured. This usually means GSL was incorrectly installed"
          echo "*** or that you have moved GSL since it was installed. In the latter case, you"
          echo "*** may want to edit the gsl-config script: $GSL_CONFIG" ])
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
       fi
     fi
#     GSL_CFLAGS=""
#     GSL_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(GSL_CFLAGS)
  AC_SUBST(GSL_LIBS)
  rm -f conf.gsltest
])
