//
// gtybalt.cc
//

/*
 *  gTybalt Copyright (C) 2001 Stefan Weinzierl and Roberta Marani
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <string>
#include <iostream>
#include <cstdio>

#include "gtybalt.h"
#include "config.h"

#include "TROOT.h"
#include "TApplication.h"
#include "TSystem.h"
#include "Getline.h"

#include <pthread.h>

void* gTybalt_pthread_fct(void* arg);
void initialize_gTybalt_pthread_condition(void);

#define DATA_BEGIN  ((char) 2)
#define DATA_END    ((char) 5)
#define DATA_ESCAPE ((char) 27)

// need an instance of TROOT
TROOT root("Rint","The ROOT Interactive Interface");

extern int gGinacTexmacs;

int main(int argc, char **argv)
{
  int j;
  int state;
  char command[1024];
  const char *command_pointer;
  char key;

#ifdef HAVE_NESTEDSUMS
  int have_nestedsums = 1;
#else // ! HAVE_NESTEDSUMS
  int have_nestedsums = 0;
#endif // HAVE_NESTEDSUMS

  TApplication *theApp = new TApplication("ROOT example", &argc, argv, NULL, 0);  

  // set flag for pretty print output
  if ( (argc==2) && (0==strcmp(argv[1],"--texmacs")) )
    {
      gGinacTexmacs = 1;
    }
  else
    {
      gGinacTexmacs = 0;
    } 

  // logon macro ?
  const char *logon = "gtybalt_logon";
  char *have_macro = gSystem->Which(TROOT::GetMacroPath(),logon,kReadPermission);
  if (have_macro)
    {
      theApp->ProcessFile(logon);
    } 
  else 
    {
      // the default behaviour
      gROOT->ProcessLine("#include <iostream>");
      gROOT->ProcessLine("#include <string>");
      gSystem->Load("libgtybaltdict.so");
      gROOT->ProcessLine("using namespace GiNaC;");
      if (have_nestedsums) gROOT->ProcessLine("using namespace nestedsums;");
      gROOT->ProcessLine("greeting();");
    }
  delete [] have_macro;


  // create a threat
  pthread_t thread_1;
  pthread_attr_t attr;

  pthread_attr_init(&attr);
  initialize_gTybalt_pthread_condition();
  int ierr = pthread_create( &thread_1, &attr, gTybalt_pthread_fct, NULL);

  pthread_attr_destroy(&attr);


  // initialize eventloop
  state=0;

  // enter the event loop
  while (0==state) {
    if (gGinacTexmacs==1)
      {
        // use a readline function without echo
        // cin >> command breaks a command line apart when it encounters a space
	j=0;
	key = getchar();
	while ( (int) key != 10)
	  {
	    command[j] = key;
	    j++;
	    key = getchar();
	  }
	command[j]=0;
      }
    else
      {
        // getline from root package
        // can use the history here
	command_pointer = Getline("gTybalt> ");
	Gl_histadd(command_pointer);
	strcpy(command,command_pointer);
        // the root version seems to attach a carriage return
        // get rid of that thing
	j=0;
	key = command[j];
	while ( (int) key != 10)
	  {
	    command[j] = key;
	    j++;
	    key = command[j];
	  }
	command[j]=0;
      }

    // exit event loop if command==quit
    if (strcmp (command,"quit") == 0) break;

    // texmacs wants DATA_BEGIN, verbatim:
    if (gGinacTexmacs==1) 
      {
	std::cout << DATA_BEGIN << "verbatim:";
      }

    // send the command to CINT for execution
    gROOT->ProcessLine(command);

    // texmacs wants DATA_END and fflush
    if (gGinacTexmacs==1)
      {
	std::cout << DATA_END;
	fflush (stdout);
      }
  
  } // end event loop

  // clean up for exit
  delete theApp;
  return 0;
}


