//
// convenience.h
//

/*
 *  gTybalt Copyright (C) 2011 Stefan Weinzierl and Roberta Marani
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GTYBALT_CONVENIENCE_H__
#define __GTYBALT_CONVENIENCE_H__

#if !defined(__CINT__)
#include "ginac/ginac.h"
#else
#include "../ginac_headers/ginac.h"
#endif

// -------------------------------------------------------------------------------------------------
// in GiNaC, the three functions "is_a<T>", "is_exactly_a<T>" and "ex_to<T>" are based on templates
// in CINT we have to define a seperate function for every type

bool is_a_symbol(const GiNaC::ex & arg);
bool is_exactly_a_symbol(const GiNaC::ex & arg);
const GiNaC::symbol & ex_to_symbol(const GiNaC::ex & arg);

bool is_a_constant(const GiNaC::ex & arg);
bool is_exactly_a_constant(const GiNaC::ex & arg);
const GiNaC::constant & ex_to_constant(const GiNaC::ex & arg);

bool is_a_numeric(const GiNaC::ex & arg);
bool is_exactly_a_numeric(const GiNaC::ex & arg);
const GiNaC::numeric & ex_to_numeric(const GiNaC::ex & arg);

bool is_a_wildcard(const GiNaC::ex & arg);
bool is_exactly_a_wildcard(const GiNaC::ex & arg);
const GiNaC::wildcard & ex_to_wildcard(const GiNaC::ex & arg);

bool is_a_matrix(const GiNaC::ex & arg);
bool is_exactly_a_matrix(const GiNaC::ex & arg);
const GiNaC::matrix & ex_to_matrix(const GiNaC::ex & arg);

bool is_a_relational(const GiNaC::ex & arg);
bool is_exactly_a_relational(const GiNaC::ex & arg);
const GiNaC::relational & ex_to_relational(const GiNaC::ex & arg);

bool is_a_tensor(const GiNaC::ex & arg);
bool is_exactly_a_tensor(const GiNaC::ex & arg);
const GiNaC::tensor & ex_to_tensor(const GiNaC::ex & arg);

bool is_a_tensdelta(const GiNaC::ex & arg);
bool is_exactly_a_tensdelta(const GiNaC::ex & arg);
const GiNaC::tensdelta & ex_to_tensdelta(const GiNaC::ex & arg);

bool is_a_idx(const GiNaC::ex & arg);
bool is_exactly_a_idx(const GiNaC::ex & arg);
const GiNaC::idx & ex_to_idx(const GiNaC::ex & arg);

bool is_a_varidx(const GiNaC::ex & arg);
bool is_exactly_a_varidx(const GiNaC::ex & arg);
const GiNaC::varidx & ex_to_varidx(const GiNaC::ex & arg);

bool is_a_lst(const GiNaC::ex & arg);
bool is_exactly_a_lst(const GiNaC::ex & arg);
const GiNaC::lst & ex_to_lst(const GiNaC::ex & arg);

bool is_a_indexed(const GiNaC::ex & arg);
bool is_exactly_a_indexed(const GiNaC::ex & arg);
const GiNaC::indexed & ex_to_indexed(const GiNaC::ex & arg);

bool is_a_clifford(const GiNaC::ex & arg);
bool is_exactly_a_clifford(const GiNaC::ex & arg);
const GiNaC::clifford & ex_to_clifford(const GiNaC::ex & arg);

bool is_a_color(const GiNaC::ex & arg);
bool is_exactly_a_color(const GiNaC::ex & arg);
const GiNaC::color & ex_to_color(const GiNaC::ex & arg);

bool is_a_function(const GiNaC::ex & arg);
bool is_exactly_a_function(const GiNaC::ex & arg);
const GiNaC::function & ex_to_function(const GiNaC::ex & arg);

bool is_a_fderivative(const GiNaC::ex & arg);
bool is_exactly_a_fderivative(const GiNaC::ex & arg);
const GiNaC::fderivative & ex_to_fderivative(const GiNaC::ex & arg);

bool is_a_ncmul(const GiNaC::ex & arg);
bool is_exactly_a_ncmul(const GiNaC::ex & arg);
const GiNaC::ncmul & ex_to_ncmul(const GiNaC::ex & arg);

bool is_a_pseries(const GiNaC::ex & arg);
bool is_exactly_a_pseries(const GiNaC::ex & arg);
const GiNaC::pseries & ex_to_pseries(const GiNaC::ex & arg);

bool is_a_power(const GiNaC::ex & arg);
bool is_exactly_a_power(const GiNaC::ex & arg);
const GiNaC::power & ex_to_power(const GiNaC::ex & arg);

bool is_a_mul(const GiNaC::ex & arg);
bool is_exactly_a_mul(const GiNaC::ex & arg);
const GiNaC::mul & ex_to_mul(const GiNaC::ex & arg);

bool is_a_add(const GiNaC::ex & arg);
bool is_exactly_a_add(const GiNaC::ex & arg);
const GiNaC::add & ex_to_add(const GiNaC::ex & arg);

// -------------------------------------------------------------------------------------------------

#endif // ndef __GTYBALT_CONVENIENCE_H__
