//
// plot.cc
//

/*
 *  gTybalt Copyright (C) 2001 Stefan Weinzierl and Roberta Marani
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

//#include <string>
//#include <iostream>
//#include <sstream>

#include "TROOT.h"
#include "TRint.h"
#include "TApplication.h"
#include "TSystem.h"

#include "TCanvas.h"
#include "TF1.h"
#include "TF2.h"

#include "plot.h"
#include "threads.h"

// global variables
#include "globals.h"

// -----------------------------------------------------
// plotting of functions

int plot(const char *formula, double xmin, double xmax)
{
  TCanvas *canvas = new TCanvas("canvas","gTybalt plot output",1);
  TF1 *f1 = new TF1("f1",formula,(Double_t) xmin,(Double_t) xmax);

  f1->Draw();
  gPad->Update();
  gApplication->Run(kTRUE);

  delete f1;
  delete canvas;

  return 0;
}

// -----------------------------------------------------

int plot(GiNaC::ex expr, GiNaC::ex x, double xmin, double xmax)
{
  if (!gTybalt_pthread_flag)
    {
      // use two global variables for expr and x
      gTybaltPlotExpr     = expr;
      gTybaltPlotSymbol_x = x;

      gTybaltPlot_xmin = xmin;
      gTybaltPlot_xmax = xmax;

      set_gTybalt_pthread_flag(1);
    }

  return 0;
}

int plot_1d_imp(void)
{
  TCanvas *canvas = new TCanvas("canvas","gTybalt plot output",1);
  TF1 *f1 = new TF1("f1",fct_to_plot_1d, 
		    (Double_t) gTybaltPlot_xmin, (Double_t) gTybaltPlot_xmax,
		    0);

  f1->Draw();
  gPad->Update();
  gApplication->Run(kTRUE);

  delete f1;
  delete canvas;

  return 0;
}

Double_t fct_to_plot_1d(Double_t *x, Double_t *par)
{
  // one dimensional plot uses only x[0]

  // get expr and xx from global variables
  GiNaC::ex xx   = gTybaltPlotSymbol_x;
  GiNaC::ex expr = gTybaltPlotExpr;

  GiNaC::ex expr2 = expr.subs(xx==x[0]).evalf();
  GiNaC::numeric expr3 = GiNaC::ex_to<GiNaC::numeric>(expr2);
  Double_t erg = (Double_t) expr3.to_double();

  return( erg );
}

// --------------------------------------------------------
// scalar function of two variables

int plot(GiNaC::ex expr, GiNaC::ex x, GiNaC::ex y, 
         double xmin, double xmax, double ymin, double ymax)
{
  if (!gTybalt_pthread_flag)
    {
      // use two global variables for expr and x
      gTybaltPlotExpr   = expr;
      gTybaltPlotSymbol_x = x;
      gTybaltPlotSymbol_y = y;
      
      gTybaltPlot_xmin = xmin;
      gTybaltPlot_xmax = xmax;
      gTybaltPlot_ymin = ymin;
      gTybaltPlot_ymax = ymax;

      set_gTybalt_pthread_flag(2);
    }

  return 0;
}

int plot_2d_imp(void)
{
  TCanvas *canvas = new TCanvas("canvas","gTybalt plot output",1);
  TF2 *f1 = new TF2("f1",fct_to_plot_2d, 
		    (Double_t) gTybaltPlot_xmin, (Double_t) gTybaltPlot_xmax,
		    (Double_t) gTybaltPlot_ymin, (Double_t) gTybaltPlot_ymax,
		    0);

  f1->Draw("surf1");
  gPad->Update();
  gApplication->Run(kTRUE);

  delete f1;
  delete canvas;

  return 0;
}

Double_t fct_to_plot_2d(Double_t *x, Double_t *par)
{
  // two dimensional plot uses x[0], x[1]

  // get expr and xx from global variables
  GiNaC::ex xx   = gTybaltPlotSymbol_x;
  GiNaC::ex yy   = gTybaltPlotSymbol_y;
  GiNaC::ex expr = gTybaltPlotExpr;

  GiNaC::ex expr2 = expr.subs(GiNaC::lst{xx==x[0],yy==x[1]}).evalf();
  GiNaC::numeric expr3 = GiNaC::ex_to<GiNaC::numeric>(expr2);
  Double_t erg = (Double_t) expr3.to_double();

  return( erg );
}



