//
// print.cc
//

/*
 *  gTybalt Copyright (C) 2001 Stefan Weinzierl and Roberta Marani
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <string>
#include <iostream>
#include <sstream>

#define DATA_BEGIN  ((char) 2)
#define DATA_END    ((char) 5)
#define DATA_ESCAPE ((char) 27)

#include "print.h"

// includes eqascii
#include "extern.h"

// global variables
#include "globals.h"

// ---------------------------------------------

int print(int x)
{
  std::cout << x << std::endl;
  return 0;
}

int print(double x)
{
  std::cout << x << std::endl;
  return 0;
}

int print(GiNaC::ex expr)
{
  if (gGinacTexmacs) 
    {
      prettyprint(expr);
    }
  else 
    {
      prettyprint(expr);
    }

  return 0;
}

// -----------------------------------------------------

int rawprint(GiNaC::ex expr)
{
  if (gGinacTexmacs) 
    {
      expr.print(GiNaC::print_context(std::cout));
    }
  else 
    {
      // print in ginsh style
      expr.print(GiNaC::print_context(std::cout));
    }

  // in any case, send a line feed
  std::cout << std::endl;

  return 0;
}

// -----------------------------------------------------

int prettyprint(GiNaC::ex expr, int textwidth)
{
  // GiNaC::eout is available here

  if (gGinacTexmacs) 
    {
      // close verbatim, open latex
      std::cout << DATA_END << DATA_BEGIN << "latex:$";
    }

  if (gGinacTexmacs) 
    {
      expr.print(GiNaC::print_latex(std::cout));
    }
  else 
    {
      // use eqascii
      std::ostringstream ost;
      expr.print(GiNaC::print_latex(ost));
      std::string s = ost.str();
      int ipos = 0;
      while ( ipos != -1 )
	{
	  ipos = backslash_washer(s,ipos);
	}
      std::cout << std::endl;
      eqascii(s.c_str(),textwidth);
    }

  // in any case, send a line feed
  std::cout << std::endl;

  if (gGinacTexmacs) 
    {
      // close latex, reopen verbatim
      std::cout << "$" << DATA_END << DATA_BEGIN << "verbatim:";
    }

  return 0;
}

// -----------------------------------------------------
// Eqascii does not handle properly \sin etc.
// 
// backslah_washer removes the backslashes
//
// This routine should become obsolete one day...

int backslash_washer(std::string &s, int ipos)
{
  int length = s.length();
  int pos;

  pos = s.find("\\exp");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"exp");
    return 0;
    }
  pos = s.find("\\ln");
  if ( pos > -1 && pos < length )
    { s.replace(pos,3,"log");
    return 0;
    }
  pos = s.find("\\sin");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"sin");
    return 0;
    }
  pos = s.find("\\cos");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"cos");
    return 0;
    }
  pos = s.find("\\tan");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"tan");
    return 0;
    }
  pos = s.find("\\arcsin");
  if ( pos > -1 && pos < length )
    { s.replace(pos,7,"asin");
    return 0;
    }
  pos = s.find("\\arccos");
  if ( pos > -1 && pos < length )
    { s.replace(pos,7,"acos");
    return 0;
    }
  pos = s.find("\\arctan");
  if ( pos > -1 && pos < length )
    { s.replace(pos,7,"atan");
    return 0;
    }
  pos = s.find("\\sinh");
  if ( pos > -1 && pos < length )
    { s.replace(pos,5,"sinh");
    return 0;
    }
  pos = s.find("\\cosh");
  if ( pos > -1 && pos < length )
    { s.replace(pos,5,"cosh");
    return 0;
    }
  pos = s.find("\\tanh");
  if ( pos > -1 && pos < length )
    { s.replace(pos,5,"tanh");
    return 0;
    }
  pos = s.find("\\mbox{abs}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,10,"abs");
    return 0;
    }
  pos = s.find("\\mbox{csgn}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,11,"csgn");
    return 0;
    }
  pos = s.find("\\mbox{atan2}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,12,"atan2");
    return 0;
    }
  pos = s.find("\\mbox{asinh}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,12,"asinh");
    return 0;
    }
  pos = s.find("\\mbox{acosh}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,12,"acosh");
    return 0;
    }
  pos = s.find("\\mbox{atanh}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,12,"atanh");
    return 0;
    }
  pos = s.find("\\mbox{Li}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,9,"Li");
    return 0;
    }
  pos = s.find("\\mbox{zeta}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,11,"zeta");
    return 0;
    }
  pos = s.find("\\log \\Gamma");
  if ( pos > -1 && pos < length )
    { s.replace(pos,11,"log Gamma");
    return 0;
    }
  pos = s.find("\\mbox{B}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,8,"B");
    return 0;
    }
  pos = s.find("\\mbox{psi}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,10,"psi");
    return 0;
    }
  pos = s.find("\\mbox{factorial}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,16,"factorial");
    return 0;
    }
  pos = s.find("\\mbox{binomial}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,15,"binomial");
    return 0;
    }
  pos = s.find("\\mathcal{O}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,11,"Order");
    return 0;
    }

  // nestedsums
  pos = s.find("\\mbox{H}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,8,"H");
    return 0;
    }
  pos = s.find("\\mbox{S}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,8,"S");
    return 0;
    }
  pos = s.find("\\mbox{TFA}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,10,"TFA");
    return 0;
    }
  pos = s.find("\\mbox{TFB}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,10,"TFB");
    return 0;
    }
  pos = s.find("\\mbox{TFC}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,10,"TFC");
    return 0;
    }
  pos = s.find("\\mbox{TFD}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,10,"TFD");
    return 0;
    }
  pos = s.find("\\mbox{empty_list_of_tgamma}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,27,"emptylistoftgamma");
    return 0;
    }
  pos = s.find("\\mbox{mZeta}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,12,"mZeta");
    return 0;
    }
  pos = s.find("\\mbox{Harmonic_sum}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,19,"HarmonicSum");
    return 0;
    }
  pos = s.find("\\mbox{EulerZagier_sum}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,22,"EulerZagierSum");
    return 0;
    }
  pos = s.find("\\mbox{S_sum_infinity}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,21,"SsumInfinity");
    return 0;
    }
  pos = s.find("\\mbox{S_sum}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,12,"Ssum");
    return 0;
    }
  pos = s.find("\\mbox{Z_sum}");
  if ( pos > -1 && pos < length )
    { s.replace(pos,12,"Zsum");
    return 0;
    }

  // and the greek alphabet
  pos = s.find("\\alpha");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"alpha");
    return 0;
    }
  pos = s.find("\\beta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,5,"beta");
    return 0;
    }
  pos = s.find("\\gamma");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"gamma");
    return 0;
    }
  pos = s.find("\\delta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"delta");
    return 0;
    }
  pos = s.find("\\epsilon");
  if ( pos > -1 && pos < length )
    { s.replace(pos,8,"epsilon");
    return 0;
    }
  pos = s.find("\\varepsilon");
  if ( pos > -1 && pos < length )
    { s.replace(pos,11,"varepsilon");
    return 0;
    }
  pos = s.find("\\zeta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,5,"zeta");
    return 0;
    }
  pos = s.find("\\eta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"eta");
    return 0;
    }
  pos = s.find("\\theta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"theta");
    return 0;
    }
  pos = s.find("\\vartheta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,9,"vartheta");
    return 0;
    }
  pos = s.find("\\iota");
  if ( pos > -1 && pos < length )
    { s.replace(pos,5,"iota");
    return 0;
    }
  pos = s.find("\\kappa");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"kappa");
    return 0;
    }
  pos = s.find("\\lambda");
  if ( pos > -1 && pos < length )
    { s.replace(pos,7,"lambda");
    return 0;
    }
  pos = s.find("\\mu");
  if ( pos > -1 && pos < length )
    { s.replace(pos,3,"mu");
    return 0;
    }
  pos = s.find("\\nu");
  if ( pos > -1 && pos < length )
    { s.replace(pos,3,"nu");
    return 0;
    }
  pos = s.find("\\xi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,3,"xi");
    return 0;
    }
  pos = s.find("\\omicron");
  if ( pos > -1 && pos < length )
    { s.replace(pos,8,"omicron");
    return 0;
    }
  pos = s.find("\\pi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,3,"pi");
    return 0;
    }
  pos = s.find("\\varpi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"varpi");
    return 0;
    }
  pos = s.find("\\rho");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"rho");
    return 0;
    }
  pos = s.find("\\varrho");
  if ( pos > -1 && pos < length )
    { s.replace(pos,7,"varrho");
    return 0;
    }
  pos = s.find("\\sigma");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"sigma");
    return 0;
    }
  pos = s.find("\\varsigma");
  if ( pos > -1 && pos < length )
    { s.replace(pos,9,"varsigma");
    return 0;
    }
  pos = s.find("\\tau");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"tau");
    return 0;
    }
  pos = s.find("\\upsilon");
  if ( pos > -1 && pos < length )
    { s.replace(pos,8,"upsilon");
    return 0;
    }
  pos = s.find("\\phi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"phi");
    return 0;
    }
  pos = s.find("\\varphi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,7,"varphi");
    return 0;
    }
  pos = s.find("\\chi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"chi");
    return 0;
    }
  pos = s.find("\\psi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"psi");
    return 0;
    }
  pos = s.find("\\omega");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"omega");
    return 0;
    }


  pos = s.find("\\Gamma");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"Gamma");
    return 0;
    }
  pos = s.find("\\Delta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"Delta");
    return 0;
    }
  pos = s.find("\\Theta");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"Theta");
    return 0;
    }
  pos = s.find("\\Lambda");
  if ( pos > -1 && pos < length )
    { s.replace(pos,7,"Lambda");
    return 0;
    }
  pos = s.find("\\Xi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,3,"Xi");
    return 0;
    }
  pos = s.find("\\Pi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,3,"Pi");
    return 0;
    }
  pos = s.find("\\Sigma");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"Sigma");
    return 0;
    }
  pos = s.find("\\Upsilon");
  if ( pos > -1 && pos < length )
    { s.replace(pos,8,"Upsilon");
    return 0;
    }
  pos = s.find("\\Phi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"Phi");
    return 0;
    }
  pos = s.find("\\Psi");
  if ( pos > -1 && pos < length )
    { s.replace(pos,4,"Psi");
    return 0;
    }
  pos = s.find("\\Omega");
  if ( pos > -1 && pos < length )
    { s.replace(pos,6,"Omega");
    return 0;
    }

  // matrices
  // removes {cc...} after begin{array}
  pos = s.find("\\begin{array}{");
  if ( pos > -1 && pos < length )
    { 
      int end_pos = s.find("}",pos+13);
      s.replace(pos,end_pos-pos+1,"\\begin{array}");
      return 0;
    }

  // brackets {( ... )}  --> ( ... )
  // this is the last replacement
  pos = s.find("{(",ipos);
  if ( pos > -1 && pos < length )
    { 
      int end_pos = pos;
      int b_state = 1;
      while (b_state)
	{
	  end_pos = s.find(")}",end_pos+2);
	  if ( end_pos > -1 && end_pos < length )
	    {
	      int o_b = 0;
	      int c_b = 0;
	      int temp_pos = pos+1;
	      while ( temp_pos > -1 && temp_pos < end_pos )
		{
		  // find the number of opening brackets between pos and end_pos
		  temp_pos = s.find("(",temp_pos+1);
		  if ( temp_pos > -1 && temp_pos < end_pos ) o_b++;
		}
	      temp_pos = pos+1;
	      while ( temp_pos > -1 && temp_pos < end_pos )
		{
		  // find the number of closing brackets between pos and end_pos
		  temp_pos = s.find(")",temp_pos+1);
		  if ( temp_pos > -1 && temp_pos < end_pos ) c_b++;
		}
	      if ( o_b == c_b ) b_state=0;
	    }
	  else
	    {
	      b_state=0;
	    }
	}

      if ( end_pos > -1 && end_pos < length )
	{ 
	  s.replace(end_pos,2,")");
	  s.replace(pos,2,"(");
	  return pos;
	}
    }


  return -1;
}


